#version 100

precision mediump float;

uniform sampler2D texture;
varying vec2 texCoord;

uniform float opacity;
uniform bool block;
uniform float blockLeft;
uniform float blockRight;
uniform vec4 blockColor;

uniform float offsetTopY;
uniform float offsetBottomY;

void main() {
    bool showBlock = block && texCoord.x >= blockLeft && texCoord.x <= blockRight;
    //make sure outbound of texture pixels is transparent
    bool clearColor = texCoord.y > offsetTopY || texCoord.y < offsetBottomY;
    vec4 texColor = texture2D(texture, texCoord) * vec4(!clearColor);
    // Division by zero will not fail OpenGL but cause unspecified behaviour.
    // However, it is acceptable as the 4th component of the vector will be 0 anyway.
    vec4 premultipliedColor = vec4(texColor.rgb / texColor.a, texColor.a * opacity);
    vec4 fragColor = premultipliedColor * vec4(!showBlock) + blockColor * vec4(showBlock);
    gl_FragColor = fragColor;
}
